<?php

/** mlbl_genealogie */

declare(strict_types=1);

use Fisharebest\Localization\Translation;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Module\AbstractModule;
use Fisharebest\Webtrees\Module\ModuleCustomInterface;
use Fisharebest\Webtrees\Module\ModuleCustomTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsInterface;
use Illuminate\Support\Collection;

/** Class mlbl_genealogie */
return new class extends AbstractModule implements ModuleCustomInterface, ModuleHistoricEventsInterface
{
	use ModuleCustomTrait;
	use ModuleHistoricEventsTrait;

	public function title(): string
	{return 'MaLiBeLe Généalogie';}

	public function description(): string
	{return "Quelques évènements importants pour les généalogistes.";}

	public function customModuleAuthorName(): string 
	{return 'Roland Bouat';}

	/** Date = version au format AAAA-MM-JJ de préférence */
	public function customModuleVersion(): string 
	{return '2023-09-08';} 

	/** URL du fichier texte contenant la référence de la dernière version */
	public function customModuleLatestVersionUrl(): string
	{return 'https://dekri.net/webtrees_histoire-derniere_version.txt';} 

	/** URL de l'éventuelle page d'aide et/ou de présentation */
	public function customModuleSupportUrl(): string 
	{return 'https://dekri.net/spip.php?article61';}


	/**
	 * Ce module doit-il être activé lors de sa première installation ?
	 * @return bool => false (conseillé) ou true
	 */
	public function isEnabledByDefault(): bool
	{return false;}

	/**
	 * Tous les événements fournis par ce module.
	 * @return Collection<int,string>
	 */
	public function historicEventsAll(): Collection
	{
	switch (I18N::languageTag()) {
		/** Langues utilisées */
		case 'fr':
        case 'fr-CA':
		return new Collection([
		/*# généalogie */
"1 EVEN Roger Bacon propose une réforme du calendrier\n2 TYPE Généalogie\n2 DATE 1267\n2 NOTE voir [Roger_Bacon](https://fr.wikipedia.org/wiki/Roger_Bacon)",
"1 EVEN Passage du calendrier julien au calendrier grégorien\n2 TYPE Généalogie\n2 DATE 04 OCT 1582\n2 NOTE voir [Passage_du_calendrier_julien_au_calendrier_grégorien](https://fr.wikipedia.org/wiki/Passage_du_calendrier_julien_au_calendrier_grégorien)",
"1 EVEN Instauration de l’obligation de tenue des registres en double\n2 TYPE Généalogie\n2 DATE APR 1667\n2 NOTE Ordonnance de Procédure civile de Saint-Germain-en-Laye (code Louis)\n3 CONT voir [Registres_paroissiaux](https://fr.geneawiki.com/wiki/Registres_paroissiaux)",
"1 EVEN Passage du calendrier julien au calendrier grégorien en Alsace\n2 TYPE Généalogie\n2 DATE 05 FEB 1682\n2 NOTE voir [Passage_au_calendrier_grégorien ](https://fr.wikipedia.org/wiki/Passage_au_calendrier_grégorien )",
"1 EVEN Obligation de signer les registres\n2 TYPE Généalogie\n2 DATE 9 APR 1736\n2 NOTE Signatures obligatoires pour les curés, les comparants et les témoins ou indiquer ne savoir signer\n3 CONT voir [Registres_paroissiaux](https://fr.geneawiki.com/wiki/Registres_paroissiaux)",
"1 EVEN Passage du calendrier julien au calendrier grégorien en Lorraine\n2 TYPE Généalogie\n2 DATE 16 FEB 1760\n2 NOTE voir [Passage_au_calendrier_grégorien](https://fr.wikipedia.org/wiki/Passage_au_calendrier_grégorien)",
"1 EVEN Les non catholiques peuvent bénéficier de l’état civil sans se convertir\n2 TYPE Généalogie\n2 DATE 7 nov 1787\n2 NOTE L’édit de Versailles ou édit de tolérance est signé par Louis XVI\\n3 CONT voir [Édit_de_Versailles](https://fr.wikipedia.org/wiki/Édit_de_Versailles)",
"1 EVEN État civil confié aux maires\n2 TYPE Généalogie\n2 DATE 20 SEP 1792\n2 NOTE Le décret du 20 septembre 1792 retire l’état civil aux curés (BMS) pour le confier aux maires\n3 CONT voir [État_civil](https://fr.wikipedia.org/wiki/État_civil)",
"1 EVEN Institution du calendrier républicain dit « calendrier révolutionnaire »\n2 TYPE Généalogie\n2 DATE 22 SEP 1792\n2 NOTE voir [Calendrier_républicain](https://fr.wikipedia.org/wiki/Calendrier_républicain)",
"1 EVEN Entrée en vigueur du calendrier républicain (ou calendrier révolutionnaire)\n2 TYPE Généalogie\n2 DATE 6 oct 1793\n2 NOTE 15 vendémiaire an II\n3 CONT voir [Calendrier_républicain](https://fr.wikipedia.org/wiki/Calendrier_républicain)",
"1 EVEN Du 1er vendémiaire an VII au 7 thermidor an VIII (du 22 septembre 1798 au 26 juillet 1800) les mariages ont lieu au chef lieu de canton.\n2 TYPE Généalogie\n2 DATE 22 SEP 1798\n2 NOTE voir [Canton_français](https://fr.wikipedia.org/wiki/Canton_français)",

				]);

			default:
				return new Collection();
		}
	}
};
/** Bonne utilisation */