<?php

/** mlbl_histoire */

declare(strict_types=1);

use Fisharebest\Localization\Translation;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Module\AbstractModule;
use Fisharebest\Webtrees\Module\ModuleCustomInterface;
use Fisharebest\Webtrees\Module\ModuleCustomTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsInterface;
use Illuminate\Support\Collection;

/** Class mlbl_histoire */
return new class extends AbstractModule implements ModuleCustomInterface, ModuleHistoricEventsInterface
{
	use ModuleCustomTrait;
	use ModuleHistoricEventsTrait;

	public function title(): string
	{return 'MaLiBeLe Histoire';}

	public function description(): string
	{return "L'Histoire complète souvent les histoires individuelles.";}

	public function customModuleAuthorName(): string 
	{return 'Roland Bouat';}

	/** Date = version au format AAAA-MM-JJ de préférence */
	public function customModuleVersion(): string 
	{return '2023-09-08';} 

	/** URL du fichier texte contenant la référence de la dernière version */
	public function customModuleLatestVersionUrl(): string
	{return 'https://dekri.net/webtrees_histoire-derniere_version.txt';} 

	/** URL de l'éventuelle page d'aide et/ou de présentation */
	public function customModuleSupportUrl(): string 
	{return 'https://dekri.net/spip.php?article61';}


	/**
	 * Ce module doit-il être activé lors de sa première installation ?
	 * @return bool => false (conseillé) ou true
	 */
	public function isEnabledByDefault(): bool
	{return false;}

	/**
	 * Tous les événements fournis par ce module.
	 * @return Collection<int,string>
	 */
	public function historicEventsAll(): Collection
	{
	switch (I18N::languageTag()) {
		/** Langues utilisées */
		case 'fr':
        case 'fr-CA':
		return new Collection([
		/*# Histoire */
"1 EVEN Défaite de Vercingétorix face à Jules César à Alésia\n2 TYPE Histoire\n2 DATE -52\n2 NOTE voir [Siège_d’Alésia](https://fr.wikipedia.org/wiki/Siège_d’Alésia)",
"1 EVEN Construction du Pont du Gard\n2 TYPE Histoire\n2 DATE FROM 40 TO 50\n2 NOTE voir [Pont_du_Gard](https://fr.wikipedia.org/wiki/Pont_du_Gard)",
"1 EVEN Défaite des Musulmans à Poitiers face à Charles Martel\n2 TYPE Histoire\n2 DATE 732\n2 NOTE voir [Bataille_de_Poitiers_(732)](https://fr.wikipedia.org/wiki/Bataille_de_Poitiers_(732))",
"1 EVEN Réalisation des premières levées de la Loire.\n2 TYPE Histoire\n2 DATE 840\n2 NOTE Les premières 'grandes levées' ont, quant à elles, démarré plutôt vers 1200.\n3 CONT voir [Levée_de_la_Loire](https://fr.wikipedia.org/wiki/Levée_de_la_Loire)",
"1 EVEN Le pape Urbain II lance la première Croisade\n2 TYPE Histoire\n2 DATE 27 NOV 1095\n2 NOTE voir [Première_croisade](https://fr.wikipedia.org/wiki/Première_croisade)",
"1 EVEN Victoire de Philippe II Auguste lors de la bataille Bouvines\n2 TYPE Histoire\n2 DATE 1214\n2 NOTE voir [Bataille_de_Bouvines](https://fr.wikipedia.org/wiki/Bataille_de_Bouvines)",
"1 EVEN Mort de Saint Louis à Tunis lors de la 8e et dernière croisade\n2 TYPE Histoire\n2 DATE 1270\n2 NOTE voir [Huitième_croisade](https://fr.wikipedia.org/wiki/Huitième_croisade)",
"1 EVEN Guerre de Cent Ans\n2 TYPE Histoire\n2 DATE 24 MAY 1337\n2 NOTE voir [Guerre_de_Cent_Ans](https://fr.wikipedia.org/wiki/Guerre_de_Cent_Ans)",
"1 EVEN Traité de Brétigny\n2 TYPE Histoire\n2 DATE 8 MAY 1360\n2 NOTE Libération de Jean II « le Bon » roi de France contre rançon et une grande partie du sud-ouest de la France\n3 CONT voir [Traité_de_Brétigny](https://fr.wikipedia.org/wiki/Traité_de_Brétigny)",
"1 EVEN Libération d’Orléans par Jeanne d’Arc contre les Anglais\n2 TYPE Histoire\n2 DATE 1429\n2 NOTE voir [Siège_d'Orléans_(1428-1429)](https://fr.wikipedia.org/wiki/Siège_d'Orléans_(1428-1429))",
"1 EVEN Jeanne d’Arc est brûlée vive à Rouen\n2 TYPE Histoire\n2 DATE 30 MAY 1431\n2 NOTE voir [Jeanne_d'Arc](https://fr.wikipedia.org/wiki/Jeanne_d'Arc)",
"1 EVEN Claude de France épouse le futur François Ier\n2 TYPE Histoire\n2 DATE 13 JUN 1514\n2 NOTE voir [Claude_de_France_(1499-1524)](https://fr.wikipedia.org/wiki/Claude_de_France_(1499-1524))",
"1 EVEN Louis XII se marie en secondes noces avec Mary Tudor, princesse d’Angleterre\n2 TYPE Histoire\n2 DATE 9 OCT 1514\n2 NOTE voir [Marie_Tudor_(1496-1533)](https://fr.wikipedia.org/wiki/Marie_Tudor_(1496-1533))",
"1 EVEN François Ier triomphe lors de la bataille de Marignan\n2 TYPE Histoire\n2 DATE 1515\n2 NOTE voir [Bataille_de_Marignan](https://fr.wikipedia.org/wiki/Bataille_de_Marignan)",
"1 EVEN Henri II épouse Catherine de Médicis\n2 TYPE Histoire\n2 DATE 28 OCT 1533\n2 NOTE voir [Catherine_de_Médicis](https://fr.wikipedia.org/wiki/Catherine_de_Médicis)",
"1 EVEN François Ier meurt\n2 TYPE Histoire\n2 DATE 31 MAR 1547\n2 NOTE voir [François_Ier_(roi_de_France)](https://fr.wikipedia.org/wiki/François_Ier_(roi_de_France))",
"1 EVEN Calais redevient française\n2 TYPE Histoire\n2 DATE JAN 1558\n2 NOTE Les troupes du duc de Guise lieutenant général du roi Henri II, reprennent la ville de Calais, dernière possession anglaise en territoire français.\n3 CONT voir [Siège_de_Calais_(1558)](https://fr.wikipedia.org/wiki/Siège_de_Calais_(1558))",
"1 EVEN  François II épouse Marie Stuart la jeune reine d’Écosse\n2 TYPE Histoire\n2 DATE 24 APR 1558\n2 NOTE voir [Marie_Stuart](https://fr.wikipedia.org/wiki/Marie_Stuart)",
"1 EVEN La conjuration d’Amboise\n2 TYPE Histoire\n2 DATE 16 MAR 1560\n2 NOTE voir [Conjuration_d'Amboise](https://fr.wikipedia.org/wiki/Conjuration_d'Amboise)",
"1 EVEN François II meurt à 16 ans.\n2 TYPE Histoire\n2 DATE 10 JUL 1559\n2 NOTE voir [François_II_(roi_de_France)](https://fr.wikipedia.org/wiki/François_II_(roi_de_France))",
"1 EVEN Le massacre à Wassy qui annonce le début des guerres de Religion\n2 TYPE Histoire\n2 DATE 1 MAR 1562\n2 NOTE voir [Massacre_de_Wassy](https://fr.wikipedia.org/wiki/Massacre_de_Wassy)",
"1 EVEN Le mariage d’Henri de Navarre et de Marguerite de Valois (la reine Margot) annonce le signal du massacre de la Saint Barthélemy\n2 TYPE Histoire\n2 DATE 18 AUG 1572\n2 NOTE voir [Marguerite_de_France_(1553-1615)](https://fr.wikipedia.org/wiki/Marguerite_de_France_(1553-1615))",
"1 EVEN Massacre des protestants par les catholiques lors de la nuit de la Saint Barthélémy\n2 TYPE Histoire\n2 DATE 24 AUG 1572\n2 NOTE voir [Marguerite_de_France_(1553-1615)](https://fr.wikipedia.org/wiki/Marguerite_de_France_(1553-1615))",
"1 EVEN Le duc de Guise est assassiné\n2 TYPE Histoire\n2 DATE 23 DEC 1588\n2 NOTE voir [Assassinat_d'Henri_de_Guise](https://fr.wikipedia.org/wiki/Assassinat_d'Henri_de_Guise)",
"1 EVEN Henri III est assassiné par Jacques Clément\n2 TYPE Histoire\n2 DATE 1 AUG 1589\n2 NOTE voir [Assassinat_d'Henri_III](https://fr.wikipedia.org/wiki/Assassinat_d'Henri_III)",
"1 EVEN Calais passe brièvement sous contrôle espagnol\n2 TYPE Histoire\n2 DATE FROM 1595 TO1597\n2 NOTE voir [Siege_of_Calais_(1596)](https://en.wikipedia.org/wiki/Siege_of_Calais_(1596))",
"1 EVEN Promulgation de l’édit de Nantes par Henri IV\n2 TYPE Histoire\n2 DATE APR 1598\n2 NOTE L’édit de Nantes accorde aux protestants des droits religieux\n3 CONT voir [Édit_de_Nantes](https://fr.wikipedia.org/wiki/Édit_de_Nantes)",
"1 EVEN Henri IV est assassiné par Ravaillac\n2 TYPE Histoire\n2 DATE 1610\n2 NOTE voir [Assassinat_d'Henri_IV](https://fr.wikipedia.org/wiki/Assassinat_d'Henri_IV)",
"1 EVEN Ouverture des États Généraux\n2 TYPE Histoire\n2 DATE 27 OCT 1614\n2 NOTE voir [États_généraux_de_1614](https://fr.wikipedia.org/wiki/États_généraux_de_1614)",
"1 EVEN L’édit de Pau\n2 TYPE Histoire\n2 DATE OCT 1620\n2 NOTE La Navarre et le Béarn sont rattachés au royaume\n3 CONT voir [Édit_de_Pau](https://fr.wikipedia.org/wiki/Édit_de_Pau)",
"1 EVEN Capitulation de La Rochelle\n2 TYPE Histoire\n2 DATE 28 OCT 1628\n2 NOTE voir [Siège_de_La_Rochelle_(1627-1628)](https://fr.wikipedia.org/wiki/Siège_de_La_Rochelle_(1627-1628))",
"1 EVEN Capitulation d’Alès\n2 TYPE Histoire\n2 DATE 17 JUN 1629\n2 NOTE voir [Siège_d'Alés](https://fr.wikipedia.org/wiki/Siège_d'Alés)",
"1 EVEN Édit de grâce (Paix d’Alès) de Louis XIII en faveur des protestants\n2 TYPE Histoire\n2 DATE 28 JUN 1629\n2 NOTE L’édit révoque le versant militaire de l’édit de Nantes qui permettait aux protestants de conserver des places fortes militaires mais il maintient la liberté de culte dans tout le royaume\n3 CONT voir [Paix_d'Alès](https://fr.wikipedia.org/wiki/Paix_d'Alès)",
"1 EVEN Création de la compagnie des îles d’Amérique\n2 TYPE Histoire\n2 DATE 12 FEB 1635\n2 NOTE Colonisation de la Guadeloupe et de laMartinique\n3 CONT voir [Compagnie_des_Îles_d’Amérique](https://fr.wikipedia.org/wiki/Compagnie_des_Îles_d’Amérique)",
"1 EVEN La France déclare la guerre à l’Espagne\n2 TYPE Histoire\n2 DATE 19 MAY 1635\n2 NOTE voir [Guerre_franco-espagnole](https://fr.wikipedia.org/wiki/Guerre_franco-espagnole)",
"1 EVEN Répression contre les croquants du Périgord\n2 TYPE Histoire\n2 DATE 1 JUN 1637\n2 NOTE voir [Révolte_des_croquants](https://fr.wikipedia.org/wiki/Révolte_des_croquants)",
"1 EVEN Échec des Espagnols devant Leucate\n2 TYPE Histoire\n2 DATE 28 SEP 1637\n2 NOTE voir [Bataille_de_Leucate](https://fr.wikipedia.org/wiki/Bataille_de_Leucate)",
"1 EVEN Les armées françaises commandées par le Maréchal de la Meilleraye s’empare de Hesdin\n2 TYPE Histoire\n2 DATE 29 JUN 1639\n2 NOTE voir [Hesdin#Histoire](https://fr.wikipedia.org/wiki/Hesdin#Histoire)",
"1 EVEN Création du louis d’or qui remplace l’écu\n2 TYPE Histoire\n2 DATE 31 MAR 1640\n2 NOTE voir [Louis_(monnaie)](https://fr.wikipedia.org/wiki/Louis_(monnaie))",
"1 EVEN Prise d’Arras par les armées de Louis XIII\n2 TYPE Histoire\n2 DATE 10 AUG 1640\n2 NOTE voir [Siège_d'Arras_(1640)](https://fr.wikipedia.org/wiki/Siège_d'Arras_(1640))",
"1 EVEN Les armées françaises s’emparent de Perpignan après 10 mois de siège\n2 TYPE Histoire\n2 DATE 9 SEP 1642\n2 NOTE voir [Siège_de_Perpignan_(1642)](https://fr.wikipedia.org/wiki/Siège_de_Perpignan_(1642))",
"1 EVEN Victoire de Condé sur les Espagnols à Rocroi\n2 TYPE Histoire\n2 DATE 19 MAY 1643\n2 NOTE voir [Bataille_de_Rocroi](https://fr.wikipedia.org/wiki/Bataille_de_Rocroi)",
"1 EVEN Défaite française devant Armentières face aux Espagnols\n2 TYPE Histoire\n2 DATE 4 JUN 1647\n2 NOTE voir [Siège_d'Armentières_(1647)](https://fr.wikipedia.org/wiki/Siège_d'Armentières_(1647))",
"1 EVEN Traités de Westphalie : Conclusion de la guerre de Trente Ans et de la guerre de Quatre-Vingts Ans.\n2 TYPE Histoire\n2 DATE 24 OCT 1648\n2 NOTE Annexion officielle par Louis XIV des Trois-Évêchés (Metz, Toul et Verdun) déjà sous tutelle depuis 1552, de la Décapole (Colmar, Obernai, Rosheim mais pas Mulhouse)…  \n3 CONT \n3 CONT voir [Traités_de_Westphalie](https://fr.wikipedia.org/wiki/Traités_de_Westphalie)",
"1 EVEN Début de la « fronde princière »\n2 TYPE Histoire\n2 DATE 18 JAN 1650\n2 NOTE Elle se terminera par le départ de Mazarin. \n3 CONT voir [Fronde_(histoire)](https://fr.wikipedia.org/wiki/Fronde_(histoire))",
"1 EVEN Paix de Bordeaux marquant la fin de la Fronde.\n2 TYPE Histoire\n2 DATE 31 JUL 1653\n2 NOTE voir [Fronde_(histoire)](https://fr.wikipedia.org/wiki/Fronde_(histoire))",
"1 EVEN Création de l’hôpital général de la Salpétrière à Paris\n2 TYPE Histoire\n2 DATE 22 APR 1656\n2 NOTE voir [Hôpital_de_la_Salpétrièreoee](https://fr.wikipedia.org/wiki/Hôpital_de_la_Salpétrièreoee)",
"1 EVEN Bataille des Dunes. \n2 TYPE Histoire\n2 DATE 14 JUN 1658\n2 NOTE Dunkerque française depuis 1646 au service des Espagnols depuis 1652 est assiégée et passe sous domination anglaise (la ville sera vendue à la France en 1662).\n3 CONT voir [Bataille_des_Dunes_(1658)](https://fr.wikipedia.org/wiki/Bataille_des_Dunes_(1658))",
"1 EVEN Traité des Pyrénées\n2 TYPE Histoire\n2 DATE 07 NOV 1659\n2 NOTE Louis XIV récupère le comté d’Artois (sauf Aire et Saint-Omer qui ne reviendront français qu’en 1678)\n3 CONT voir [Traité_des_Pyrénées](https://fr.wikipedia.org/wiki/Traité_des_Pyrénées)",
"1 EVEN Début du règne effectif du Roi Soleil\n2 TYPE Histoire\n2 DATE 1661\n2 NOTE La mort de Mazarin lui permet de régner seul.\n3 CONT voir [Louis_XIV](https://fr.wikipedia.org/wiki/Louis_XIV)",
"1 EVEN Guerre de Dévolution entre la France et l’Espagne\n2 TYPE Histoire\n2 DATE 17 JUL 1667\n2 NOTE 1ère guerre de Louis XIV \n3 CONT voir [Guerre_de_Dévolution](https://fr.wikipedia.org/wiki/Guerre_de_Dévolution)",
"1 EVEN Lille, ville espagnole, redevient française\n2 TYPE Histoire\n2 DATE 28 AUG 1667\n2 NOTE voir [Histoire_de_Lille](https://fr.wikipedia.org/wiki/Histoire_de_Lille)",
"1 EVEN Traité d’Aix-la-Chapelle\n2 TYPE Histoire\n2 DATE 02 MAY 1668\n2 NOTE Fin de la guerre de Dévolution\n3 CONT voir [Traité_d'Aix-la-Chapelle_(1668)](https://fr.wikipedia.org/wiki/Traité_d'Aix-la-Chapelle_(1668))",
"1 EVEN Traité de Nimègue\n2 TYPE Histoire\n2 DATE 10 AUG 1678\n2 NOTE Fin de la guerre de Hollande opposant Louis XIV et ses alliés à Guillaume III d’Orange-Nassau stathouder des provinces de Hollande et Léopold Ier empereur du Saint-Empire notamment. La Franche-Comté devient française ainsi que Cassel, Bailleul, Cambrai, Valenciennes…\n3 CONT voir [Traité_de_Nimègue](https://fr.wikipedia.org/wiki/Traité_de_Nimègue)",
"1 EVEN Création de la Comédie Française\n2 TYPE Histoire\n2 DATE 22 OCT 1680\n2 NOTE voir [Comédie-Française](https://fr.wikipedia.org/wiki/Comédie-Française)",
"1 EVEN Capitulation de Strasbourg qui devient donc française.\n2 TYPE Histoire\n2 DATE 30 SEP 1681\n2 NOTE voir [Capitulation_de_Strasbourg](https://fr.wikipedia.org/wiki/Capitulation_de_Strasbourg)",
"1 EVEN Édit de Fontainebleau révoquant l’édit de Nantes\n2 TYPE Histoire\n2 DATE 18 OCT 1685\n2 NOTE voir [çdit_de_Fontainebleau_(1685)](https://fr.wikipedia.org/wiki/çdit_de_Fontainebleau_(1685))",
"1 EVEN Création de la capitation impôt direct universel par Louis XIV.\n2 TYPE Histoire\n2 DATE 18 JAN 1695\n2 NOTE Il est le premier nouvel impôt direct créé depuis la royalisation de la taille au XVe siècle. \n3 CONT voir [Capitation](https://fr.wikipedia.org/wiki/Capitation)",
"1 EVEN Béthune devient néerlandaise\n2 TYPE Histoire\n2 DATE 29 AUG 1710\n2 NOTE Après six semaines de siège Béthune devient néerlandaise jusqu’au traité d’Utrecht en 1713.\n3 CONT voir [Guerre_de_Succession_d'Espagne ](https://fr.wikipedia.org/wiki/Guerre_de_Succession_d'Espagne )",
"1 EVEN Traités d’Utrecht :  La principauté d’Orange est annexée à la France.\n2 TYPE Histoire\n2 DATE 1713\n2 NOTE Fin de la guerre de Succession d’Espagne. Les traités fixent notamment le tracé de la frontière franco-belge.\n3 CONT voir [Traités_d'Utrecht_(1713)](https://fr.wikipedia.org/wiki/Traités_d'Utrecht_(1713))",
"1 EVEN Traité de Vienne :  La Lorraine est attribuée à Louis XV qui la donne en viager à son beau-père Stanislas Leszczyński.\n2 TYPE Histoire\n2 DATE 18 NOV 1738\n2 NOTE Elle sera formellement annexée par la France en 1766 à la mort de ce dernier. \n3 CONT \n3 CONT voir [Traité_de_Vienne_(1738)](https://fr.wikipedia.org/wiki/Traité_de_Vienne_(1738))",
"1 EVEN Traité de Versailles :  la république de Gênes cède la Corse à Louis XV. \n2 TYPE Histoire\n2 DATE 15 MAY 1768\n2 NOTE voir [Traité_de_Versailles_(1768)](https://fr.wikipedia.org/wiki/Traité_de_Versailles_(1768))",
"1 EVEN Abolition de la royauté (Révolution Française) =  Naissance de la Ière République\n2 TYPE histoire\n2 DATE 21 SEP 1792\n2 NOTE voir [Proclamation_de_l'abolition_de_la_royauté](https://fr.wikipedia.org/wiki/Proclamation_de_l'abolition_de_la_royauté)",
"1 EVEN Début de la période dite « la Terreur »\n2 TYPE histoire\n2 DATE APR 1793\n2 NOTE Période comprise entre la mise en place du Tribunal Révolutionnaire de Paris et la chute de Robespierre\n3 CONT voir [Terreur_(Révolution_française)](https://fr.wikipedia.org/wiki/Terreur_(Révolution_française))",
"1 EVEN Chute de Robespierre et fin de la Terreur\n2 TYPE Histoire\n2 DATE 26 JUL 1794\n2 NOTE 8 thermidor an II\n3 CONT voir [Maximilien_de_Robespierre](https://fr.wikipedia.org/wiki/Maximilien_de_Robespierre)",
"1 EVEN Annexion des « neufs départements réunis » par la République française\n2 TYPE Histoire\n2 DATE 31 AUG 1795\n2 NOTE La Convention nationale française adopte une nouvelle division du territoire de la Belgique, du pays de Liège, et d'autres pays adjacents, en neuf arrondissements ou départements\n3 CONT voir [Départements_réunis](https://fr.wikipedia.org/wiki/Départements_réunis)",
"1 EVEN L’armée de la République française avance en Italie et proclame une République ligurienne « sœur » à Gênes. \n2 TYPE Histoire\n2 DATE 1797\n2 NOTE  \n3 CONT voir [République_de_Gênes](https://fr.wikipedia.org/wiki/République_de_Gênes)",
"1 EVEN La loi Jourdan-Debrel du 19 fructidor an VI impose une « conscription universelle et obligatoire » de tous les Français âgés de 20 à 25 ans.\n2 TYPE Histoire\n2 DATE 5 SEP 1798\n2 NOTE voir [Loi_Jourdan-Delbrel](https://fr.wikipedia.org/wiki/Loi_Jourdan-Delbrel)",
"1 EVEN Création du Conseil de révision\n2 TYPE Histoire\n2 DATE 19 DEC 1804\n2 NOTE Le décret impérial du 29 décembre 1804 met en place le conseil de révision et le tirage au sort des conscrits. Il est possible de se faire remplacer moyennant finances.\n3 CONT voir [Service_militaire_en_France](https://fr.wikipedia.org/wiki/Service_militaire_en_France)",
"1 EVEN La République ligurienne est annexée à l’Empire français. \n2 TYPE Histoire\n2 DATE 1805\n2 NOTE Savone est chef-lieu du département de Montenotte. En 1814 la République de Gênes sera rétablie puis annexée par le royaume de Sardaigne.\n3 CONT \n3 CONT voir [République_ligurienne](https://fr.wikipedia.org/wiki/République_ligurienne)",
"1 EVEN La commission Napoléon II, commission de gouvernement, présidée par Joseph Fouché dirige la France\n2 TYPE Histoire\n2 DATE 23 JUN 1815\n2 NOTE Jusqu’au retour en 1815 de Louis XVIII\n3 CONT voir [Commission_Napoléon_II](https://fr.wikipedia.org/wiki/Commission_Napoléon_II)",
"1 EVEN Renforcement l’interdiction de la traite négrière\n2 TYPE Histoire\n2 DATE 4 MAR 1831\n2 NOTE Il faudra attendre 1848 pour que l’esclavage soit définitivement aboli.\n3 CONT voir [Loi_du_4_mars_1831](https://fr.wikipedia.org/wiki/Loi_du_4_mars_1831)",
"1 EVEN Début de la conquête de l’Algérie par la France\n2 TYPE Histoire\n2 DATE 14 JUN 1834\n2 NOTE Elle débute à Sidi-Ferruch par le débarquement de l’armée d’Afrique commandée par le comte de Bourmont. Alger tombe le 5 juillet.\n3 CONT voir [Conquête_de_l'Algérie_par_la_France ](https://fr.wikipedia.org/wiki/Conquête_de_l'Algérie_par_la_France )",
"1 EVEN Sous l’impulsion de Victor Schœlcher le gouvernement provisoire de la IIe République abolit l’esclavage dans tous les territoires français.\n2 TYPE Histoire\n2 DATE 27 APR 1848\n2 NOTE voir [Abolition_de_l'esclavage]( https://fr.wikipedia.org/wiki/Abolition_de_l'esclavage)",
"1 EVEN Création de trois départements d’Algérie (hors Sahara) : Oran à l’ouest Alger au centre et Constantine à l’est.\n2 TYPE Histoire\n2 DATE 09 DEC 1848 \n2 NOTE Algérie française\n3 CONT voir [Départements_en_Algérie_française](https://fr.wikipedia.org/wiki/Départements_en_Algérie_française)",
"1 EVEN Le droit de vote est accordé à tous les hommes en France.\n2 TYPE Histoire\n2 DATE 1848\n2 NOTE Jusqu’à cette date, un seuil d’imposition, le cens, était nécessaire pour avoir le droit de voter.\n3 CONT voir [Droit_de_vote](https://fr.wikipedia.org/wiki/Droit_de_vote)",
"1 EVEN Traité de Turin :  le duché de Savoie et le comté de Nice sont réunis à la France.\n2 TYPE Histoire\n2 DATE 24 MAR 1860\n2 NOTE voir [Traité_de_Turin_(1860) ](https://fr.wikipedia.org/wiki/Traité_de_Turin_(1860) )",
"1 EVEN Guerre franco-allemande : Napoléon III déclare la guerre au royaume de Prusse le 19 juillet 1870.\n2 TYPE Histoire\n2 DATE 19 JUL 1870\n2 NOTE Il capitule le 2 septembre. L’armistice général intervient le 15 février 1871.\n3 CONT voir [Guerre_franco-allemande_de_1870]( https://fr.wikipedia.org/wiki/Guerre_franco-allemande_de_1870)",
"1 EVEN Proclamation de la IIIe République par Léon Gambetta.\n2 TYPE Histoire\n2 DATE 4 SEP 1870\n2 NOTE voir [Proclamation_de_la_République_française_du_4_septembre_1870](https://fr.wikipedia.org/wiki/Proclamation_de_la_République_française_du_4_septembre_1870)",
"1 EVEN Traité de Francfort :  Toute l’Alsace sauf le Territoire de Belfort est annexée par l’Allemagne ainsi qu’une partie de la Lorraine.\n2 TYPE Histoire\n2 DATE 10 MAY 1871\n2 NOTE voir [Traité_de_Francfort](https://fr.wikipedia.org/wiki/Traité_de_Francfort)",
"1 EVEN Loi relative à la séparation des Églises et de l’État\n2 TYPE Histoire\n2 DATE 09 DEC 1905\n2 NOTE Émile Loubet est alors président de la République française.\n3 CONT voir [271400-la-loi-du-9-decembre-1905-de-separation-des-eglises-et-de-letat](https://www.vie-publique.fr/fiches/271400-la-loi-du-9-decembre-1905-de-separation-des-eglises-et-de-letat)",
"1 EVEN Première Guerre mondiale\n2 TYPE Histoire\n2 DATE 28 JUL 1914\n2 NOTE L’Autriche-Hongrie déclare la guerre à la Serbie le 28 juillet 1914. Le gouvernement français décrète la mobilisation générale le 2 août (Raymond Poincaré est président depuis 1913). L’Allemagne déclare la guerre à la Russie le 1er août à la France le 3.\n3 CONT voir [Première_Guerre_mondiale](https://fr.wikipedia.org/wiki/Première_Guerre_mondiale)",
"1 EVEN Traité de Versailles :  l’Alsace-Lorraine redevient française.\n2 TYPE Histoire\n2 DATE 28 JUN 1919\n2 NOTE voir [Traité_de_Versailles](https://fr.wikipedia.org/wiki/Traité_de_Versailles)",
"1 EVEN Front populaire\n2 TYPE Histoire\n2 DATE 03 MAY 1936\n2 NOTE Il introduit de nombreuses réformes en matière économique et sociale : les congés payés la réduction du temps de travail avec la semaine de quarante heures et l’établissement des conventions collectives.\n3 CONT voir [Front_populaire_(France)](https://fr.wikipedia.org/wiki/Front_populaire_(France))",
"1 EVEN Seconde Guerre mondiale\n2 TYPE Histoire\n2 DATE 3 SEP 1939\n2 NOTE La France du président Albert Lebrun et le Royaume-Uni du roi Édouard VIII déclarent la guerre au Troisième Reich d’Adolf Hitler qui vient d’envahir la Pologne.\n3 CONT voir [Seconde_Guerre_mondiale](https://fr.wikipedia.org/wiki/Seconde_Guerre_mondiale)",
"1 EVEN Les femmes obtiennent le droit de vote en France.\n2 TYPE Histoire\n2 DATE 1944\n2 NOTE voir [Droit_de_vote_des_femmes](https://fr.wikipedia.org/wiki/Droit_de_vote_des_femmes)",
"1 EVEN Création de la Sécurité sociale\n2 TYPE Histoire\n2 DATE 19 OCT 1945\n2 NOTE  instituée par une ordonnance du Gouvernement provisoire de la République française présidé par De Gaulle.\n3 CONT voir [Sécurité_sociale_en_France](https://fr.wikipedia.org/wiki/Sécurité_sociale_en_France)",
"1 EVEN Promulgation de la  IVe République\n2 TYPE Histoire\n2 DATE 24 OCT 1946\n2 NOTE Le président de la République est élu par le Parlement composé par la réunion des deux chambres pour une durée de sept ans. Son rôle est essentiellement représentatif.\n3 CONT voir [Constitution_française_du_27_octobre_1946](https://fr.wikipedia.org/wiki/Constitution_française_du_27_octobre_1946)",
"1 EVEN Traité de Rome > création de la Communauté économique européenne et du Marché commun européen.\n2 TYPE Histoire\n2 DATE 25 MAR 1957\n2 NOTE  René Coty est alors président de la République.\n3 CONT voir [Traité_instituant_la_Communauté_économique_européenne](https://fr.wikipedia.org/wiki/Traité_instituant_la_Communauté_économique_européenne)",
"1 EVEN Promulgation de la Ve République\n2 TYPE Histoire\n2 DATE 5 OCT 1958\n2 NOTE voir [Cinquième_République_(France)](https://fr.wikipedia.org/wiki/Cinquième_République_(France))",
"1 EVEN Les accords d’Évian mettent fin à la guerre d’Algérie. L’indépendance est proclamée le 3 juillet.\n2 TYPE Histoire\n2 DATE 18 MAR 1962\n2 NOTE Guerre d’Algérie\n3 CONT voir [Accords_d'çvian](https://fr.wikipedia.org/wiki/Accords_d'çvian)",
"1 EVEN Le référendum de 1962 introduit l’élection du président de la République au suffrage universel direct.\n2 TYPE Histoire\n2 DATE 28 OCT 1962\n2 NOTE Le premier scrutin de ce type a lieu en 1965 .\n3 CONT voir [Référendum_constitutionnel_français_de_1962](https://fr.wikipedia.org/wiki/Référendum_constitutionnel_français_de_1962)",
"1 EVEN Évènements de mai-juin 1968\n2 TYPE Histoire\n2 DATE MAY 1968\n2 NOTE A partir du 13 mai 1968 la plus importante grève générale du XXe siècle en France paralyse complètement le pays pendant plusieurs semaines.\n3 CONT voir [Mai_68](https://fr.wikipedia.org/wiki/Mai_68)",
"1 EVEN Traité de Maastricht : traité fondateur de l’Union européenne.\n2 TYPE Histoire\n2 DATE 07 FEB 1992\n2 NOTE voir [Traité_de_Maastricht ](https://fr.wikipedia.org/wiki/Traité_de_Maastricht )",
"1 EVEN Passage à l’euro au niveau Européen\n2 TYPE Histoire\n2 DATE 1 JAN 2002\n2 NOTE Il succède à l'ECU, « l'unité de compte européenne » mise en service en 1979. \n3 CONT voir [Euro](https://fr.wikipedia.org/wiki/Euro)",

				]);

			default:
				return new Collection();
		}
	}
};
/** Bonne utilisation */