<?php

/** mlbl_sciences */

declare(strict_types=1);

use Fisharebest\Localization\Translation;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Module\AbstractModule;
use Fisharebest\Webtrees\Module\ModuleCustomInterface;
use Fisharebest\Webtrees\Module\ModuleCustomTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsInterface;
use Illuminate\Support\Collection;

/** Class mlbl_sciences */
return new class extends AbstractModule implements ModuleCustomInterface, ModuleHistoricEventsInterface
{
	use ModuleCustomTrait;
	use ModuleHistoricEventsTrait;

	public function title(): string
	{return 'MaLiBeLe Sciences';}

	public function description(): string
	{return "Évènements scientifiques importants dns le monde";}

	public function customModuleAuthorName(): string 
	{return 'Roland Bouat';}

	/** Date = version au format AAAA-MM-JJ de préférence */
	public function customModuleVersion(): string 
	{return '2023-09-08';} 

	/** URL du fichier texte contenant la référence de la dernière version */
	public function customModuleLatestVersionUrl(): string
	{return 'https://dekri.net/webtrees_histoire-derniere_version.txt';} 

	/** URL de l'éventuelle page d'aide et/ou de présentation */
	public function customModuleSupportUrl(): string 
	{return 'https://dekri.net/spip.php?article61';}


	/**
	 * Ce module doit-il être activé lors de sa première installation ?
	 * @return bool => false (conseillé) ou true
	 */
	public function isEnabledByDefault(): bool
	{return false;}

	/**
	 * Tous les événements fournis par ce module.
	 * @return Collection<int,string>
	 */
	public function historicEventsAll(): Collection
	{
	switch (I18N::languageTag()) {
		/** Langues utilisées */
		case 'fr':
        case 'fr-CA':
		return new Collection([
		/*# scinces */
"1 EVEN Youri Gagarine est le premier homme dans l’espace.\n2 TYPE Sciences\n2 DATE 12 APR 1961\n2 NOTE Astronautique\n3 CONT voir [Youri_Gagarine](https://fr.wikipedia.org/wiki/Youri_Gagarine)",
"1 EVEN Neil Armstrong effectue le premier pas de l’homme sur la Lune.\n2 TYPE Sciences\n2 DATE 21 JUL 1969\n2 NOTE Astronautique\n3 CONT voir [Neil_Armstrong](https://fr.wikipedia.org/wiki/Neil_Armstrong)",
"1 EVEN Les lois de Kepler sur le mouvement des planètes\n2 TYPE Sciences\n2 DATE 1609\n2 NOTE Astronomie : Johannes Kepler énonce les deux premières lois du mouvement des planètes.\n3 CONT voir [Lois_de_Kepler](https://fr.wikipedia.org/wiki/Lois_de_Kepler)",
"1 EVEN Loi universelle de la gravitation\n2 TYPE Sciences\n2 DATE 1685\n2 NOTE Astronomie : Isaac Newton formule la loi universelle de la gravitation.\n3 CONT voir [Loi_universelle_de_la_gravitation](https://fr.wikipedia.org/wiki/Loi_universelle_de_la_gravitation)",
"1 EVEN Comète de Halley\n2 TYPE Sciences\n2 DATE 1705\n2 NOTE Astronomie : Edmond Halley postule que les comètes qui étaient apparues dans le ciel en 1531, 1607 et 1682 sont en fait une seule et même comète voyageant sur une orbite elliptique qu’elle décrit en 76 ans. Il prédit qu’elle reviendra en 1758 (1759 en réalité).\n3 CONT voir [Comète_de_Halley](https://fr.wikipedia.org/wiki/Comète_de_Halley)",
"1 EVEN William Herschel (1738-1822) découvre Uranus.\n2 TYPE Sciences\n2 DATE 1781\n2 NOTE  Astronomie \n3 CONT voir [William_Herschel](https://fr.wikipedia.org/wiki/William_Herschel)",
"1 EVEN Johann Galle découvre Neptune.\n2 TYPE Sciences\n2 DATE 23 SEP 1846\n2 NOTE Astronomie : c’est l'astronome français Urbain Le Verrier, qui a prédit mathématiquement l'existence et la position de la planète.\n3 CONT voir [Découverte_de_Neptune](https://fr.wikipedia.org/wiki/Découverte_de_Neptune)",
"1 EVEN Les Soviétiques lancent le premier satellite artificiel, Spoutnik 1\n2 TYPE Sciences\n2 DATE 4 OCT 1957\n2 NOTE Astronautique\n3 CONT voir [Spoutnik_1](https://fr.wikipedia.org/wiki/Spoutnik_1)",
"1 EVEN Le comte Ferdinand von Zeppelin fait voler le 1er dirigeable rigide au-dessus du lac de Constance.\n2 TYPE Sciences\n2 DATE 02 JUL 1900\n2 NOTE Aviation\n3 CONT voir [Ballon_dirigeable](https://fr.wikipedia.org/wiki/Ballon_dirigeable)",
"1 EVEN Roland Garros accomplit la première traversée de la Méditerranée en avion.\n2 TYPE Sciences\n2 DATE 23 SEP 1913\n2 NOTE Aviation\n3 CONT voir [23-septembre-1913-roland-garros-traverse-la-méditerranée](https://www.lhistoire.fr/éphéméride/23-septembre-1913-roland-garros-traverse-la-méditerranée)",
"1 EVEN  Jean Mermoz relie Saint-Louis (Sénégal) et le Brésil en 21 heures à bord d’un Latécoère 28.\n2 TYPE Sciences\n2 DATE 13 MAY 1930\n2 NOTE Aviation\n3 CONT voir [almanach-ID-930.php](https://www.herodote.net/almanach-ID-930.php)",
"1 EVEN Nomenclature de Linné\n2 TYPE Sciences\n2 DATE 1753\n2 NOTE Biologie : Carl von Linné publie « Species plantarum » décrivant 8000 espèces de végétaux selon sa nomenclature des espèces vivantes.\n3 CONT voir [Species_plantarum](https://fr.wikipedia.org/wiki/Species_plantarum)",
"1 EVEN Lancement commercial du Minitel\n2 TYPE Sciences\n2 DATE 1982\n2 NOTE Informatique : le service fonctionnera jusqu’au 30 juin 2012. \n3 CONT voir [Minitel](https://fr.wikipedia.org/wiki/Minitel)",
"1 EVEN Les premiers compact-discs sont commercialisés en France\n2 TYPE Sciences\n2 DATE 1983\n2 NOTE Informatique : commercialisés par Sony et Philipps en décembre 1982\n3 CONT voir [Disque_compact](https://fr.wikipedia.org/wiki/Disque_compact)",
"1 EVEN Tim Berners-Lee expose les principes du système hypertexte qui deviendra le World Wide Web.\n2 TYPE Sciences\n2 DATE 1989\n2 NOTE Informatique : Le premier serveur entrera en service au CERN l’année suivante.\n3 CONT voir [Tim_Berners-Lee](https://fr.wikipedia.org/wiki/Tim_Berners-Lee)",
"1 EVEN Loi de Boyle-Mariotte (nommée loi des gaz parfaits plus tard)\n2 TYPE Sciences\n2 DATE 1662\n2 NOTE Physique : Robert Boyle formule la loi que confirmera Edmé mariotte et qui sera intégrée par Emile Clapeyron dans la loi des gaz parfaits en 1834.\n3 CONT voir [Loi_des_gaz_parfaits](https://fr.wikipedia.org/wiki/Loi_des_gaz_parfaits)",
"1 EVEN Théorie ondulatoire de la lumière\n2 TYPE Sciences\n2 DATE 1690\n2 NOTE Physique : Christian Huygens publie son Traité de la Lumière dans lequel il expose une théorie ondulatoire de la lumière. \n3 CONT voir [Traité_de_la_lumière_(Huygens)](https://fr.wikipedia.org/wiki/Traité_de_la_lumière_(Huygens))",
"1 EVEN Cerf-volant et orage de Franklin\n2 TYPE Sciences\n2 DATE 1750\n2 NOTE Physique : Benjamin Franklin propose de faire voler un cerf-volant au cours d’un orage pour démontrer la nature électrique des orages. L’expérience sera menée en 1752\n3 CONT voir [Benjamin_Franklin](https://fr.wikipedia.org/wiki/Benjamin_Franklin)",
"1 EVEN Allumage par incadescence par Émile Levassor.\n2 TYPE Sciences\n2 DATE 24 AUG 1891\n2 NOTE Automobile :  Ce sont les problèmes d’installation du premier moteur à quatre temps (celui de Daimler) sur une voiture à quatre places par René Panhard et Émile Levassor qui ont amené à cette invention.\n3 CONT voir [index.php?title=Panhard_%26_Levassor](https://fr.wikipedia.org/w/index.php?title=Panhard_%26_Levassor)",
"1 EVEN Première relation ferroviaire régulière à 200 km/h en France\n2 TYPE Sciences\n2 DATE 15 NOV 1960\n2 NOTE Transports : Le Capitole relie Paris-Austerlitz à Toulouse par la ligne des Aubrais - Orléans à Montauban-Ville-Bourbon\n3 CONT voir [Le_Capitole_(train)](https://fr.wikipedia.org/wiki/Le_Capitole_(train))",
"1 EVEN Ouverture de la première ligne TGV entre Paris et Lyon.\n2 TYPE Sciences\n2 DATE 27 sep 1981\n2 NOTE Transports : Ligne nouvelle entre Saint Florentin et Sathonay et première exploitation commerciale\n3 CONT voir [Histoire_de_la_grande_vitesse_ferroviaire_en_France](https://fr.wikipedia.org/wiki/Histoire_de_la_grande_vitesse_ferroviaire_en_France)",
"1 EVEN Tournage par Louis Lumière du premier film 'Sortie de l’usine Lumière à Lyon'.\n2 TYPE Sciences\n2 DATE 19 MAR 1895\n2 NOTE Cinéma\n3 CONT voir [La_Sortie_de_l’usine_Lumière_à_Lyon](https://fr.wikipedia.org/wiki/La_Sortie_de_l’usine_Lumière_à_Lyon)",

				]);

			default:
				return new Collection();
		}
	}
};
/** Bonne utilisation */